# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define gcj_support 1

Distribution:	CCux
Packager:	Christian Metzen <metzench@ccux-linux.de>

Name:           xml-commons-apis
Summary:        APIs for DOM, SAX, and JAXP
Version:        1.3.04
Release:        3jpp
License:        Apache Software License/W3C/Public Domain
URL:            http://xml.apache.org/commons/
Source0:        xml-commons-external-1.3.04-src.tar.gz
Requires:       jpackage-utils
BuildRequires:  jpackage-utils
BuildRequires:  ant
Group:          Text Processing/Markup/XML
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
%if ! %{gcj_support}
BuildArch:      noarch
%endif

Provides:       xml-commons = %{version}-%{release}

Provides:       jaxp = 1.3
Provides:       xml-commons-jaxp-1.3-apis = %{version}-%{release}

%if %{gcj_support}
BuildRequires:          java-gcj-compat-devel
Requires(post):         java-gcj-compat
Requires(postun):       java-gcj-compat
%endif

%description
xml-commons-apis is designed to organize and have common packaging for
the various externally-defined standard interfaces for XML. This
includes the DOM, SAX, and JAXP. 

%package manual
Summary:        Manual for %{name}
Group:          Text Processing/Markup/XML

%description manual
Manual for %{name}.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Requires(post): /bin/rm /bin/ln
Requires(postun): /bin/rm

%description javadoc
Javadoc for %{name}.

# -----------------------------------------------------------------------------

%prep
%setup -q -n external

# remove all binary libs and prebuilt javadocs
rm -rf `find . -name "*.jar" -o -name "*.gz"`
rm -rf build  

# -----------------------------------------------------------------------------

%build
export OPT_JAR_LIST="./external/build/xml-apis.jar"
ant jar javadoc

# -----------------------------------------------------------------------------

%install
rm -rf $RPM_BUILD_ROOT

# Jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p build/xml-apis.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
cp -p build/xml-apis-ext.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}-ext-%{version}.jar

# Jar versioning
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in %{name}-%{version}.jar; do ln -sf ${jar} dom3-${jar}; done)
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)
# for better interoperability with the jpp apis packages
ln -sf %{name}.jar ${RPM_BUILD_ROOT}%{_javadir}/jaxp13.jar
ln -sf %{name}.jar ${RPM_BUILD_ROOT}%{_javadir}/jaxp.jar
ln -sf %{name}.jar ${RPM_BUILD_ROOT}%{_javadir}/xml-commons-jaxp-1.3-apis.jar

# Javadocs
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr build/docs/javadoc/* \
  $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}

ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} 

# prevent apis javadoc from being included in doc
rm -rf docs/javadoc

# -----------------------------------------------------------------------------

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

# -----------------------------------------------------------------------------

%if %{gcj_support}
%post
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%if %{gcj_support}
%postun
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc LICENSE NOTICE 
%doc LICENSE.dom-documentation.txt README.dom.txt
%doc LICENSE.dom-software.txt
%doc LICENSE.sax.txt README-sax  README.sax.txt
%{_javadir}/*

%if %{gcj_support}
%dir %attr(-,root,root) %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-%{version}.jar.*
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-ext-%{version}.jar.*
%endif

%files manual
%defattr(0644,root,root,0755)
%doc build/docs/*

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/*

# -----------------------------------------------------------------------------

%if %{gcj_support}
%dir %attr(-,root,root) %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-%{version}.jar.*
%endif

%changelog
* Tue Jan 22 2008 Christian Metzen <metzench@ccux-linux.de> 1.3.04-3jpp
- rebuild with clean gcj buildchain
* Fri Jan 18 2008 Christian Metzen <metzench@ccux-linux.de> 1.3.04-2jpp
- rebuild with gcj support
* Wed Jan 16 2008 Christian Metzen <metzench@ccux-linux.de> 1.3.04-1jpp
- Initial release
- build without gcj, later rebuild with it enabled after buildchain is complete